# Generated by roxygen2: do not edit by hand

S3method(print,likert_reliability)
S3method(print,makeScalesRegression)
export(alpha)
export(alpha_sensitivity)
export(correlateScales)
export(eigenvalues)
export(lcor)
export(lexact)
export(lfast)
export(makeCorrAlpha)
export(makeCorrLoadings)
export(makeItemsScale)
export(makePaired)
export(makeRepeated)
export(makeScales)
export(makeScalesRegression)
export(ordinal_diagnostics)
export(reliability)
importFrom(Matrix,nearPD)
importFrom(Rcpp,sourceCpp)
importFrom(dplyr,bind_cols)
importFrom(graphics,abline)
importFrom(graphics,rect)
importFrom(gtools,combinations)
importFrom(matrixStats,colVars)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,cov2cor)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,model.frame)
importFrom(stats,optimize)
importFrom(stats,quantile)
importFrom(stats,rbeta)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,uniroot)
importFrom(stats,var)
importFrom(utils,combn)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
useDynLib(LikertMakeR)
