# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

lcor_C_randomised <- function(data_df, target, passes = 10L) {
    .Call('_LikertMakeR_lcor_C_randomised', PACKAGE = 'LikertMakeR', data_df, target, passes)
}

score_items_cpp <- function(dat, target_alpha, w_balance, expected_mean) {
    .Call('_LikertMakeR_score_items_cpp', PACKAGE = 'LikertMakeR', dat, target_alpha, w_balance, expected_mean)
}

